var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as React from 'react';
import { View } from 'react-native';
import { makeEvent, makeEvents } from 'yavent';
import { sidesToOffset, sidesToPadding } from '../util/sides';
import { Barometer } from './Barometer';
const emptyLayout = {
    offset: sidesToOffset([0, 0, 0, 0]),
    padding: sidesToPadding([0, 0, 0, 0])
};
/**
 * Constructs an Airship component.
 */
export function makeAirship() {
    // Static state shared by all mounted containers:
    const [onClear, emitClear] = makeEvent();
    const [onGuestsChange, emitGuestsChange] = makeEvent();
    let guests = [];
    let nextKey = 0;
    const AirshipHost = (props) => {
        const { children } = props;
        // Watch the common guest list:
        const [ourGuests, setGuests] = React.useState(guests);
        React.useEffect(() => onGuestsChange(setGuests), []);
        // Track layout changes:
        const [layout, setLayout] = React.useState(emptyLayout);
        return (React.createElement(React.Fragment, null,
            React.createElement(Barometer, { onLayout: setLayout }),
            children,
            ourGuests.map(guest => (React.createElement(View, { key: guest.key, pointerEvents: "box-none", style: Object.assign(Object.assign(Object.assign({}, layout.offset), layout.padding), { flexDirection: 'row', justifyContent: 'center', position: 'absolute' }) }, guest.element)))));
    };
    let clearing = false;
    function clear() {
        if (clearing)
            return;
        clearing = true;
        emitClear(undefined);
        clearing = false;
    }
    function show(render) {
        return __awaiter(this, void 0, void 0, function* () {
            const key = `airship${nextKey++}`;
            function remove() {
                unclear();
                guests = guests.filter(guest => guest.key !== key);
                emitGuestsChange(guests);
            }
            // Assemble the bridge:
            const [on, emit] = makeEvents();
            let bridge;
            const promise = new Promise((resolve, reject) => {
                bridge = {
                    on,
                    onResult: callback => on('result', callback),
                    reject,
                    remove,
                    resolve
                };
            });
            // Hook up events:
            promise.then(() => emit('result', undefined), () => emit('result', undefined));
            const unclear = onClear(() => emit('clear', undefined));
            // Save the guest element in the shared state:
            guests = [...guests, { key, element: render(bridge) }];
            emitGuestsChange(guests);
            return promise;
        });
    }
    return Object.assign(AirshipHost, { clear, show });
}
