import * as React from 'react';
import { Animated, Dimensions, TouchableWithoutFeedback } from 'react-native';
import { fixSides, sidesToMargin, sidesToPadding } from '../util/sides';
const safeAreaGap = 64;
/**
 * A notification that slides down from the top of the screen.
 */
export function AirshipDropdown(props) {
    const { bridge, children, onPress = () => bridge.resolve(undefined), autoHideMs = 5000, backgroundColor = 'white', borderRadius = 4, flexDirection, justifyContent, maxHeight = defaultMaxHeight(), maxWidth = 512, slideInMs = 300, slideOutMs = 500 } = props;
    const margin = sidesToMargin(fixSides(props.margin, 0));
    const padding = sidesToPadding(fixSides(props.padding, 0));
    const hiddenOffset = -(maxHeight + margin.marginBottom);
    margin.marginTop = -safeAreaGap;
    padding.paddingTop += safeAreaGap;
    // Create the animation:
    const offset = React.useRef(new Animated.Value(hiddenOffset)).current;
    React.useEffect(() => {
        let timeout;
        // Animate in:
        Animated.timing(offset, {
            toValue: 0,
            duration: slideInMs,
            useNativeDriver: true
        }).start(() => {
            // Start the auto-hide timer:
            if (autoHideMs > 0) {
                timeout = setTimeout(() => {
                    timeout = undefined;
                    bridge.resolve(undefined);
                }, autoHideMs);
            }
        });
        // Animate out:
        bridge.on('clear', () => bridge.resolve(undefined));
        bridge.on('result', () => {
            Animated.timing(offset, {
                toValue: hiddenOffset,
                duration: slideOutMs,
                useNativeDriver: true
            }).start(() => bridge.remove());
        });
        return () => {
            if (timeout != null)
                clearTimeout(timeout);
        };
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
    const bodyStyle = Object.assign(Object.assign(Object.assign({}, margin), padding), { alignSelf: 'flex-start', backgroundColor, borderBottomLeftRadius: borderRadius, borderBottomRightRadius: borderRadius, flexDirection, flexShrink: 1, justifyContent,
        maxHeight, shadowOffset: { height: 0, width: 0 }, shadowOpacity: 1, shadowRadius: 4, transform: [{ translateY: offset }], width: maxWidth // This works because flexShrink is set
     });
    return (React.createElement(TouchableWithoutFeedback, { onPress: onPress },
        React.createElement(Animated.View, { style: bodyStyle }, children)));
}
function defaultMaxHeight() {
    const { width, height } = Dimensions.get('screen');
    return 0.25 * Math.max(width, height);
}
