import * as React from 'react';
import { Animated, Text } from 'react-native';
import { fixSides, sidesToMargin, sidesToPadding } from '../util/sides';
/**
 * A semi-transparent message overlay.
 */
export function AirshipToast(props) {
    const { textSize = 14 } = props;
    const { autoHideMs = 3000, backgroundColor = 'white', borderRadius = 1.5 * textSize, bridge, children, fadeInMs = 300, fadeOutMs = 1000, maxWidth = 512, opacity: finalOpacity = 0.9, message, textColor = 'black' } = props;
    const margin = sidesToMargin(fixSides(props.margin, 2 * textSize));
    const padding = sidesToPadding(fixSides(props.padding, textSize));
    // Create the animation:
    const opacity = React.useRef(new Animated.Value(0)).current;
    React.useEffect(() => {
        let timeout;
        // Animate in:
        Animated.timing(opacity, {
            toValue: finalOpacity,
            duration: fadeInMs,
            useNativeDriver: true
        }).start(() => {
            // Start the auto-hide timer:
            if (autoHideMs > 0) {
                timeout = setTimeout(() => {
                    timeout = undefined;
                    bridge.resolve(undefined);
                }, autoHideMs);
            }
        });
        // Animate out:
        bridge.on('clear', () => bridge.resolve(undefined));
        bridge.on('result', () => {
            Animated.timing(opacity, {
                toValue: 0,
                duration: fadeOutMs,
                useNativeDriver: true
            }).start(() => bridge.remove());
        });
        return () => {
            if (timeout != null)
                clearTimeout(timeout);
        };
    });
    const bodyStyle = Object.assign(Object.assign(Object.assign({}, margin), padding), { alignItems: 'center', alignSelf: 'flex-end', backgroundColor,
        borderRadius, flexDirection: 'row', justifyContent: 'flex-start', maxWidth, opacity: opacity });
    const textStyle = {
        color: textColor,
        flexShrink: 1,
        fontSize: textSize,
        textAlign: 'center'
    };
    return (React.createElement(Animated.View, { style: bodyStyle },
        message != null ? React.createElement(Text, { style: textStyle }, message) : null,
        children));
}
