/// <reference types="react" />
import { Offset, Padding } from '../util/sides';
export interface BarometerLayout {
    offset: Offset;
    padding: Padding;
}
interface Props {
    onLayout?: (layout: BarometerLayout) => void;
}
/**
 * Measures various things about the Airship environment,
 * so we know how to position our children.
 *
 * This component mounts a view with absolute positioning,
 * and then measures that view relative to the window.
 * If a side is inset from the window edge, we use a negative offset
 * to expand it outward. If a side extends beyond the window edge,
 * we use padding to push the content inward.
 *
 * On iOS, we also mount a child inside a SafeAreaView, to measure
 * the safe area insets. We add these to the padding.
 *
 * Finally, we keep track of the keyboard, adding extra padding &
 * scheduling animations as needed.
 */
export declare function Barometer(props: Props): JSX.Element;
export {};
