import * as React from 'react';
import { OnEvents } from 'yavent';
export interface AirshipEvents {
    result: undefined;
    clear: undefined;
}
/**
 * Control panel for managing a component inside an airship.
 */
export interface AirshipBridge<T> {
    resolve: (value: T | PromiseLike<T>) => void;
    reject: (error: Error) => void;
    remove: () => void;
    on: OnEvents<AirshipEvents>;
    onResult: (callback: () => unknown) => void;
}
/**
 * Renders a component to place inside the airship.
 */
export declare type AirshipRender<T> = (bridge: AirshipBridge<T>) => React.ReactNode;
/**
 * Props the Airship container component accepts.
 */
export interface AirshipProps {
    children?: React.ReactNode;
}
/**
 * The Airship itself is a component you should mount around your main
 * scene or router.
 *
 * It has a static method anyone can call to display components.
 * The method returns a promise, which the component can use to pass values
 * to the outside world.
 */
export interface Airship extends React.FunctionComponent<AirshipProps> {
    clear: () => void;
    show: <T = void>(render: AirshipRender<T>) => Promise<T>;
}
